@@ -234,6 +234,18 @@ def test_thread_unsafe_fixtures(pytester):
         def test_capsys(capsys, num_parallel_threads):
             assert num_parallel_threads == 1
 
+        def test_capteesys(capteesys, num_parallel_threads):
+            assert num_parallel_threads == 1
+
+        def test_capsysbinary(capsysbinary, num_parallel_threads):
+            assert num_parallel_threads == 1
+
+        def test_capfd(capfd, num_parallel_threads):
+            assert num_parallel_threads == 1
+
+        def test_capfdbinary(capfdbinary, num_parallel_threads):
+            assert num_parallel_threads == 1
+
         def test_monkeypatch(monkeypatch, num_parallel_threads):
             assert num_parallel_threads == 1
 
@@ -264,6 +276,10 @@ def test_thread_unsafe_fixtures(pytester):
     result.stdout.fnmatch_lines(
         [
             "*::test_capsys PASSED *thread-unsafe*: uses thread-unsafe fixture*",
+            "*::test_capteesys PASSED *thread-unsafe*: uses thread-unsafe fixture*",
+            "*::test_capsysbinary PASSED *thread-unsafe*: uses thread-unsafe fixture*",
+            "*::test_capfd PASSED *thread-unsafe*: uses thread-unsafe fixture*",
+            "*::test_capfdbinary PASSED *thread-unsafe*: uses thread-unsafe fixture*",
             f"*::test_recwarn {WARNINGS_PASS}PASSED*",
             "*::test_custom_fixture_skip PASSED *thread-unsafe*: uses thread-unsafe fixture*",
             "*::test_custom_fixture_skip_2 PASSED *thread-unsafe*: uses thread-unsafe fixture*",
@@ -789,3 +805,19 @@ def test_ast_parsing_error():
         identify_thread_unsafe_nodes(
             RaisesError(dummy_test), frozenset(), False, False, False
         )
+
+
+def test_detect_gc_collect(pytester):
+    pytester.makepyfile("""
+    import gc
+
+    def test_gc_collect(num_parallel_threads):
+        gc.collect()
+        assert num_parallel_threads == 1
+    """)
+    result = pytester.runpytest("--parallel-threads=10", "-v")
+    result.stdout.fnmatch_lines(
+        [
+            r"*::test_gc_collect PASSED*" r"calls thread-unsafe function: gc.collect*",
+        ]
+    )
